@@ -34,12 +34,19 @@
 freq <- function(x, digits = 1, cum = FALSE, total = FALSE, exclude = NULL, sort = "", 
          valid = !(NA %in% exclude), levels = c("prefixed", "labels", "values"),
          na.last = TRUE) {
+  
   levels <- match.arg(levels)
-  if (is.table(x)) tab <- x
-  else tab <- table(labelled::to_factor(x, levels), exclude = exclude)
+  
+  if (is.table(x)) {
+    tab <- x
+  } else {
+    tab <- table(labelled::to_factor(x, levels), exclude = exclude)
+  }
+  
   effectifs <- as.vector(tab)
   pourc <- as.vector(effectifs / sum(effectifs) * 100)
   result <- data.frame(n = effectifs, pourc = pourc)
+  
   if (valid) {
     user_na <- unique(as.character(labelled::to_factor(x, levels)[is.na(x)]))
     NA.position <- which(is.na(names(tab)) | names(tab) %in% user_na)
@@ -48,15 +55,24 @@ freq <- function(x, digits = 1, cum = FALSE, total = FALSE, exclude = NULL, sort
     valid.pourc[NA.position] <- 0 # temporary 0 for cumsum
     result <- cbind(result, valid.pourc)
   }
+  
+  ## Avoid duplicate row names if both NA and "NA" in tab
+  if ("NA" %in% names(tab)) {
+    names(tab)[names(tab) == "NA"] <- "\"NA\""
+  }
   rownames(result) <- ifelse(is.na(names(tab)), "NA", names(tab))
+  
   if (sort == "inc") result <- result[order(result$n),]
   if (sort == "dec") result <- result[order(result$n, decreasing = TRUE),]
+  
   if (na.last && "NA" %in% rownames(result)) {
     result <- rbind(result[-which(rownames(result) == "NA"), ], result["NA", ])
   }
+  
   if (total) result <- rbind(result, Total = apply(result,2,sum))
   if (total & valid) 
     result[length(result$pourc),"valid.pourc"] <- 100
+  
   if (cum) {
     pourc.cum <- cumsum(result$pourc)
     if (total) pourc.cum[length(pourc.cum)] <- 100
@@ -67,17 +83,21 @@ freq <- function(x, digits = 1, cum = FALSE, total = FALSE, exclude = NULL, sort
       result <- cbind(result, valid.pourc.cum)
     }
   }
+  
   if (valid) {
     NA.position <- which(rownames(result) == "NA" | rownames(result) %in% user_na)
     result[NA.position, "valid.pourc"] <- NA
     if (cum)
       result[NA.position, "valid.pourc.cum"] <- NA
   }
+  
   names(result)[names(result) == "pourc"] <- "%"
   names(result)[names(result) == "valid.pourc"] <- "val%"
   names(result)[names(result) == "pourc.cum"] <- "%cum"
   names(result)[names(result) == "valid.pourc.cum"] <- "val%cum"
+  
   class(result) <- c("freqtab", class(result))
+  
   round(result, digits = digits)
 }
 
